==> hoteldruid-mod-ru_3.0.4-1.tar.gz: ru/clienti.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "Неверные даты"; break;
case "Si deve inserire il tipo di tariffa":  	$messaggio = "Вы должны вставить тип цен"; break;
case "tariffa":  				$messaggio = "цена"; break;
case "Non è stato ancora inserito il prezzo della":	$messaggio = "Вы должны вставить цену"; break;
case "per la settimana dal":  			$messaggio = "на неделю от"; break;
case "per il giorno dal":  			$messaggio = "на день от"; break;
case "al":  					$messaggio = "в"; break;
case "La settimana dal":  			$messaggio = "Неделя от"; break;
case "Il giorno dal":  				$messaggio = "День от"; break;
case "è piena":  				$messaggio = "заполнен"; break;
case "è pieno":  				$messaggio = "заполнен"; break;
case "Il numero di settimane del costo aggiuntivo settimanale nº":	$messaggio = "Число недель еженедельных дополнительных издержек n°"; break;
case "Il numero di giorni del costo aggiuntivo giornaliero nº":	$messaggio = "Число дней ежедневных дополнительных издержек n°"; break;
case "supera il numero totale di settimane della prenotazione":	$messaggio = "больше, чем число недель бронирования"; break;
case "supera il numero totale di giorni della prenotazione":	$messaggio = "больше, чем число дней бронирования"; break;
case "persone":  				$messaggio = "люди"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Передвижения, которые должны быть сделаны за периоды <div style=\"display: inline; color: blue;\">правила назначения 1</div>"; break;
case "Sono stati fatti i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Передвижения, которые были сделаны за периоды <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "La prenotazione dal":  			$messaggio = "Бронирование от"; break;
case "a nome di":  				$messaggio = "для Mr./Mrs."; break;
case "Non si può procedere perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "Не можем продолжать, потому что список бронирований уже изменился"; break;
case "Continua lo stesso":  			$messaggio = "Все равно продолжить"; break;
case "Torna indietro":  			$messaggio = "Назад"; break;
case "Non esistono clienti chiamati":  		$messaggio = "Нет клиентов с такими именами"; break;
case "nel database":  				$messaggio = "в базе данных"; break;
case "Inserisci i dati di un nuovo cliente":  	$messaggio = "Вставка данных о новом клиенте"; break;
case "Esistono i seguenti clienti con un cognome uguale o simile":	$messaggio = "Есть уже  клиенты с теми же или подобными именами и фамилиями"; break;
case "Esistono i seguenti clienti con un cognome e nome uguale o simile":	$messaggio = "Есть уже  клиенты с теми же или подобная именами и фамилиями"; break;
case "nato il":	  				$messaggio = "родился"; break;
case "nata il":	  				$messaggio = "родился"; break;
case "CAP":  					$messaggio = "почтовый индекс"; break;
case "Telefono":  				$messaggio = "телефон n°"; break;
case "2º telefono":  				$messaggio = "2-й телефон n°"; break;
case "3º telefono":  				$messaggio = "3-й телефон n°"; break;
case "Utilizza il cliente":  			$messaggio = "Использовать клиента"; break;
case "per la prenotazione":  			$messaggio = "для бронирования"; break;
case "Modifica i dati del cliente":  		$messaggio = "Изменить данные клиента"; break;
case "Inserisci un nuovo cliente":  		$messaggio = "Вставить нового клиента"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "Нужна  фамилия клиента"; break;
case "I dati del cliente":  			$messaggio = "Данные клиента"; break;
case "sono stati inseriti":  			$messaggio = "были вставлены"; break;
case "Inserisci o modifica i dati di un cliente":	$messaggio = "Вставьте или измените данные клиента"; break;
case "Cognome":  				$messaggio = "Фамилия"; break;
case "nome":  					$messaggio = "имя"; break;
case "sesso":  					$messaggio = "пол"; break;
case "Data di nascita":  			$messaggio = "День рождения"; break;
case "anno con 4 cifre":  			$messaggio = "год  (4 цифры)"; break;
case "Nazione":  				$messaggio = "Национальность"; break;
case "città":  					$messaggio = "город"; break;
case "Via":  					$messaggio = "Улица"; break;
case "Piazza":  				$messaggio = "Площадь"; break;
case "Viale":  					$messaggio = "Авеню"; break;
case "Piazzale":  				$messaggio = "Бульвар"; break;
case "Vicolo":  				$messaggio = "Шоссе"; break;
case "Numero di telefono":  			$messaggio = "Телефонный номер"; break;
case "Secondo telefono":  			$messaggio = "Второй телефон"; break;
case "Terzo telefono":  			$messaggio = "Третий телефон"; break;
case "Numero di fax":  				$messaggio = "Номер факса"; break;
case "Seconda persona di riferimento":  	$messaggio = "Вторая человек из справочника"; break;
case "Inserisci i dati":  			$messaggio = "Вставьте данные"; break;
case "Torna al menù principale":  		$messaggio = "Обратно к главному меню"; break;
case "Italia":  				$messaggio = ""; break;
case "non verrano modificati i dati specifici delle 2 persone di riferimento":	$messaggio = "данные, относящиеся к 2 людям  из справочника, не будут изменены"; break;
case "sono stati modificati":  			$messaggio = "были изменены"; break;
case "e":  					$messaggio = "и"; break;
case "Il numero di prenotazioni è sbagliato":	$messaggio = "Число бронирований неправильно"; break;
case "Aggiungi":  				$messaggio = "Добавить"; break;
case "Nº di tipologie da aggiungere":  		$messaggio = "Число типов для добавления"; break;
case "Non si è trovato nessun cliente chiamato":	$messaggio = "Нет клиентов по имени"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "Нет периодов в правиле назначения 1, в котором можно вставить бронирования для пользователя"; break;
case "Il numero di persone è sbagliato":  	$messaggio = "Число людей неправильно"; break;
case "I dati di un costo aggiuntivo sono errati":	$messaggio = "Данные и дополнительные издержки неправильны"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "Вы не можете вставить более чем одну дополнительную издержку с процентом от полной цены за бронирование"; break;
case "Non si puo inserire il costo aggiuntivo":	$messaggio = "Дополнительная издержка"; break;
case "in questo periodo":  			$messaggio = "не может быть вставлен в этот период"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Выберите недели, в которые действует дополнительная издержка"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Выберите дни, в которые действует дополнительная издержка"; break;
case "Continua":  				$messaggio = "Продолжить"; break;
case "Non si possono inserire altri costi":  	$messaggio = "Вы не можете вставить больше цен"; break;
case "presenti":  				$messaggio = "настоящий"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":	$messaggio = "Число людей должно быть вставлено для дополнительной издержки"; break;
case "Il costo aggiuntivo":  			$messaggio = "Дополнительная издержка"; break;
case "è incompatibile con la tariffa selezionata":	$messaggio = "несовместим с отобранной нормой"; break;
case "non può essere applicato":  		$messaggio = "не может быть применен"; break;
case "regione":  				$messaggio = "регион"; break;
case "Documento":  				$messaggio = "Документ"; break;
case "scadenza":  				$messaggio = "истечение"; break;
case "Torna all'inserimento clienti":  		$messaggio = "Обратно к добавлению клиента"; break;
case "Annulla":  				$messaggio = "Выход"; break;
case "Ospite della prenotazione":  		$messaggio = "Гость бронирования"; break;
case "tipologia":  				$messaggio = "тип"; break;
case "Ospiti della prenotazione":  		$messaggio = "Гости бронирования"; break;
case "Altri ospiti":  				$messaggio = "Другие гости"; break;
case "nato":  					$messaggio = "родился"; break;
case "nata":  					$messaggio = "родился"; break;
case "il":  					$messaggio = ""; break;
case " a":  					$messaggio = " в"; break;
case "scade":  					$messaggio = "истекает"; break;
case "cittadinanza":  				$messaggio = "национальность"; break;
case "città di nascita":  			$messaggio = "город рождения"; break;
case "reg./prov. di nascita":  			$messaggio = "регион рождения"; break;
case "nazione di nascita":  			$messaggio = "национальность рождения"; break;
case "Residenza":  				$messaggio = "Резиденция"; break;
case "reg./prov.":  				$messaggio = "регион"; break;
case "nazione":  				$messaggio = "национальность"; break;
case "rilasciato da":  				$messaggio = "выпущено"; break;
case "nazione di rilascio":  			$messaggio = "поменял национальность"; break;
case "parentela":  				$messaggio = "связанный"; break;
case "Codice fiscale":  			$messaggio = "Финансовый код"; break;
case "ln.":  					$messaggio = "ln."; break;
case "Clienti":  				$messaggio = "Clients"; break;
case "Si dovrà occupare almeno un periodo della regola di assegnazione 1":	$messaggio = "At least one period of the assignment rule 1 will have to be occupied"; break;
case "in questo periodo, già":  		$messaggio = "in this period, already"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
case "I beni richiesti dal costo":  		$messaggio = "Goods needed by cost"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "are not available in the inventory"; break;
case "Si deve inserire il numero delle persone per questa tariffa":	$messaggio = "The number of people must be inserted for this rate"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "lo sconto è sbagliato":  			$messaggio = "the discount is wrong"; break;
case "la caparra è sbagliata":  		$messaggio = "the deposit is wrong"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "le commissioni sono sbagliate":  		$messaggio = "commissions are wrong"; break;
case "lingua":  				$messaggio = "language"; break;
case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
case "La tariffa richiesta è chiusa in questo periodo":	$messaggio = "The requested rate is closed in this period"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Si deve inserire almeno una persona che possa essere ospite principale":	$messaggio = "You must insert at least one person that can be main guest"; break;
case "non si sono potuti usare":  		$messaggio = "It was not possible to use"; break;
case "letti aggiuntivi perchè non c'era nessuna tipologia di persone con quel numero":	$messaggio = "extra beds as there was no people type with that number"; break;
case "E-mail":  				$messaggio = "E-mail"; break;
case "Seconda e-mail":  			$messaggio = "Second e-mail"; break;
case "E-mail certificata (PEC) o codice destinatario":	$messaggio = "Certified e-mail"; break;
case "email":  					$messaggio = "email"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC/codice":  				$messaggio = "certified email"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-ru_3.0.8-1.tar.gz: ru/clienti.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "Неверные даты"; break;
case "Si deve inserire il tipo di tariffa":  	$messaggio = "Вы должны вставить тип цен"; break;
case "tariffa":  				$messaggio = "цена"; break;
case "Non è stato ancora inserito il prezzo della":	$messaggio = "Вы должны вставить цену"; break;
case "per la settimana dal":  			$messaggio = "на неделю от"; break;
case "per il giorno dal":  			$messaggio = "на день от"; break;
case "al":  					$messaggio = "в"; break;
case "La settimana dal":  			$messaggio = "Неделя от"; break;
case "Il giorno dal":  				$messaggio = "День от"; break;
case "è piena":  				$messaggio = "заполнен"; break;
case "è pieno":  				$messaggio = "заполнен"; break;
case "Il numero di settimane del costo aggiuntivo settimanale nº":	$messaggio = "Число недель еженедельных дополнительных издержек n°"; break;
case "Il numero di giorni del costo aggiuntivo giornaliero nº":	$messaggio = "Число дней ежедневных дополнительных издержек n°"; break;
case "supera il numero totale di settimane della prenotazione":	$messaggio = "больше, чем число недель бронирования"; break;
case "supera il numero totale di giorni della prenotazione":	$messaggio = "больше, чем число дней бронирования"; break;
case "persone":  				$messaggio = "люди"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Передвижения, которые должны быть сделаны за периоды <div style=\"display: inline; color: blue;\">правила назначения 1</div>"; break;
case "Sono stati fatti i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Передвижения, которые были сделаны за периоды <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "La prenotazione dal":  			$messaggio = "Бронирование от"; break;
case "a nome di":  				$messaggio = "для Mr./Mrs."; break;
case "Non si può procedere perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "Не можем продолжать, потому что список бронирований уже изменился"; break;
case "Continua lo stesso":  			$messaggio = "Все равно продолжить"; break;
case "Torna indietro":  			$messaggio = "Назад"; break;
case "Non esistono clienti chiamati":  		$messaggio = "Нет клиентов с такими именами"; break;
case "nel database":  				$messaggio = "в базе данных"; break;
case "Inserisci i dati di un nuovo cliente":  	$messaggio = "Вставка данных о новом клиенте"; break;
case "Esistono i seguenti clienti con un cognome uguale o simile":	$messaggio = "Есть уже  клиенты с теми же или подобными именами и фамилиями"; break;
case "Esistono i seguenti clienti con un cognome e nome uguale o simile":	$messaggio = "Есть уже  клиенты с теми же или подобная именами и фамилиями"; break;
case "nato il":	  				$messaggio = "родился"; break;
case "nata il":	  				$messaggio = "родился"; break;
case "CAP":  					$messaggio = "почтовый индекс"; break;
case "Telefono":  				$messaggio = "телефон n°"; break;
case "2º telefono":  				$messaggio = "2-й телефон n°"; break;
case "3º telefono":  				$messaggio = "3-й телефон n°"; break;
case "Utilizza il cliente":  			$messaggio = "Использовать клиента"; break;
case "per la prenotazione":  			$messaggio = "для бронирования"; break;
case "Modifica i dati del cliente":  		$messaggio = "Изменить данные клиента"; break;
case "Inserisci un nuovo cliente":  		$messaggio = "Вставить нового клиента"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "Нужна  фамилия клиента"; break;
case "I dati del cliente":  			$messaggio = "Данные клиента"; break;
case "sono stati inseriti":  			$messaggio = "были вставлены"; break;
case "Inserisci o modifica i dati di un cliente":	$messaggio = "Вставьте или измените данные клиента"; break;
case "Cognome":  				$messaggio = "Фамилия"; break;
case "nome":  					$messaggio = "имя"; break;
case "sesso":  					$messaggio = "пол"; break;
case "Data di nascita":  			$messaggio = "День рождения"; break;
case "anno con 4 cifre":  			$messaggio = "год  (4 цифры)"; break;
case "Nazione":  				$messaggio = "Национальность"; break;
case "città":  					$messaggio = "город"; break;
case "Via":  					$messaggio = "Улица"; break;
case "Piazza":  				$messaggio = "Площадь"; break;
case "Viale":  					$messaggio = "Авеню"; break;
case "Piazzale":  				$messaggio = "Бульвар"; break;
case "Vicolo":  				$messaggio = "Шоссе"; break;
case "Numero di telefono":  			$messaggio = "Телефонный номер"; break;
case "Secondo telefono":  			$messaggio = "Второй телефон"; break;
case "Terzo telefono":  			$messaggio = "Третий телефон"; break;
case "Numero di fax":  				$messaggio = "Номер факса"; break;
case "Seconda persona di riferimento":  	$messaggio = "Вторая человек из справочника"; break;
case "Inserisci i dati":  			$messaggio = "Вставьте данные"; break;
case "Torna al menù principale":  		$messaggio = "Обратно к главному меню"; break;
case "Italia":  				$messaggio = ""; break;
case "non verrano modificati i dati specifici delle 2 persone di riferimento":	$messaggio = "данные, относящиеся к 2 людям  из справочника, не будут изменены"; break;
case "sono stati modificati":  			$messaggio = "были изменены"; break;
case "e":  					$messaggio = "и"; break;
case "Il numero di prenotazioni è sbagliato":	$messaggio = "Число бронирований неправильно"; break;
case "Aggiungi":  				$messaggio = "Добавить"; break;
case "Nº di tipologie da aggiungere":  		$messaggio = "Число типов для добавления"; break;
case "Non si è trovato nessun cliente chiamato":	$messaggio = "Нет клиентов по имени"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "Нет периодов в правиле назначения 1, в котором можно вставить бронирования для пользователя"; break;
case "Il numero di persone è sbagliato":  	$messaggio = "Число людей неправильно"; break;
case "I dati di un costo aggiuntivo sono errati":	$messaggio = "Данные и дополнительные издержки неправильны"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "Вы не можете вставить более чем одну дополнительную издержку с процентом от полной цены за бронирование"; break;
case "Non si puo inserire il costo aggiuntivo":	$messaggio = "Дополнительная издержка"; break;
case "in questo periodo":  			$messaggio = "не может быть вставлен в этот период"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Выберите недели, в которые действует дополнительная издержка"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Выберите дни, в которые действует дополнительная издержка"; break;
case "Continua":  				$messaggio = "Продолжить"; break;
case "Non si possono inserire altri costi":  	$messaggio = "Вы не можете вставить больше цен"; break;
case "presenti":  				$messaggio = "настоящий"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":	$messaggio = "Число людей должно быть вставлено для дополнительной издержки"; break;
case "Il costo aggiuntivo":  			$messaggio = "Дополнительная издержка"; break;
case "è incompatibile con la tariffa selezionata":	$messaggio = "несовместим с отобранной нормой"; break;
case "non può essere applicato":  		$messaggio = "не может быть применен"; break;
case "regione":  				$messaggio = "регион"; break;
case "Documento":  				$messaggio = "Документ"; break;
case "scadenza":  				$messaggio = "истечение"; break;
case "Torna all'inserimento clienti":  		$messaggio = "Обратно к добавлению клиента"; break;
case "Annulla":  				$messaggio = "Выход"; break;
case "Ospite della prenotazione":  		$messaggio = "Гость бронирования"; break;
case "tipologia":  				$messaggio = "тип"; break;
case "Ospiti della prenotazione":  		$messaggio = "Гости бронирования"; break;
case "Altri ospiti":  				$messaggio = "Другие гости"; break;
case "nato":  					$messaggio = "родился"; break;
case "nata":  					$messaggio = "родился"; break;
case "il":  					$messaggio = ""; break;
case " a":  					$messaggio = " в"; break;
case "scade":  					$messaggio = "истекает"; break;
case "cittadinanza":  				$messaggio = "национальность"; break;
case "città di nascita":  			$messaggio = "город рождения"; break;
case "reg./prov. di nascita":  			$messaggio = "регион рождения"; break;
case "nazione di nascita":  			$messaggio = "национальность рождения"; break;
case "Residenza":  				$messaggio = "Резиденция"; break;
case "reg./prov.":  				$messaggio = "регион"; break;
case "nazione":  				$messaggio = "национальность"; break;
case "rilasciato da":  				$messaggio = "выпущено"; break;
case "nazione di rilascio":  			$messaggio = "поменял национальность"; break;
case "parentela":  				$messaggio = "связанный"; break;
case "Codice fiscale":  			$messaggio = "Финансовый код"; break;
case "ln.":  					$messaggio = "ln."; break;
case "Clienti":  				$messaggio = "Clients"; break;
case "Si dovrà occupare almeno un periodo della regola di assegnazione 1":	$messaggio = "At least one period of the assignment rule 1 will have to be occupied"; break;
case "in questo periodo, già":  		$messaggio = "in this period, already"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
case "I beni richiesti dal costo":  		$messaggio = "Goods needed by cost"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "are not available in the inventory"; break;
case "Si deve inserire il numero delle persone per questa tariffa":	$messaggio = "The number of people must be inserted for this rate"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "lo sconto è sbagliato":  			$messaggio = "the discount is wrong"; break;
case "la caparra è sbagliata":  		$messaggio = "the deposit is wrong"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "le commissioni sono sbagliate":  		$messaggio = "commissions are wrong"; break;
case "lingua":  				$messaggio = "language"; break;
case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
case "La tariffa richiesta è chiusa in questo periodo":	$messaggio = "The requested rate is closed in this period"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Si deve inserire almeno una persona che possa essere ospite principale":	$messaggio = "You must insert at least one person that can be main guest"; break;
case "non si sono potuti usare":  		$messaggio = "It was not possible to use"; break;
case "letti aggiuntivi perchè non c'era nessuna tipologia di persone con quel numero":	$messaggio = "extra beds as there was no people type with that number"; break;
case "E-mail":  				$messaggio = "E-mail"; break;
case "Seconda e-mail":  			$messaggio = "Second e-mail"; break;
case "E-mail certificata (PEC) o codice destinatario":	$messaggio = "Certified e-mail"; break;
case "email":  					$messaggio = "email"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC/codice":  				$messaggio = "certified email"; break;
case "Per questa tariffa si deve inserire un numero minimo di":	$messaggio = "For this rate you have to insert at least"; break;
case "persona":  				$messaggio = "person"; break;
case "Usa il cliente della prenotazione originale":	$messaggio = "Use the client from the original reservation"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
